Wapiti scan report

#### Summary

Category | Number of vulnerabilities found
--- | ---
% for i, vuln_name in enumerate(vulnerabilities):
% if len(vulnerabilities[vuln_name]): ${vuln_name} % else: ${vuln_name} % endif | ${len(vulnerabilities[vuln_name])}
% endfor % for i, anomaly_name in enumerate(anomalies):
% if len(anomalies[anomaly_name]): ${anomaly_name} % else: ${anomaly_name} % endif | ${len(anomalies[anomaly_name])}
% endfor % for i, additional_name in enumerate(additionals):
% if len(additionals[additional_name]): ${additional_name} % else: ${additional_name} % endif | ${len(additionals[additional_name])}
% endfor

% for i, vuln_name in enumerate(vulnerabilities): % if len(vulnerabilities[vuln_name]):

### ${vuln_name}

Description
  ${flaws[vuln_name]["desc"] | h}

% for j, vulnerability in enumerate(vulnerabilities[vuln_name]):

#### Vulnerability found in ${vulnerability["path"] | h}

    ${vulnerability["info"] | h}

    ${vulnerability["http_request"] | h}

    ${vulnerability["curl_command"] | h}

% endfor

Solutions
  ${flaws[vuln_name]["sol"]}

##### References

% for ref_name, ref_url in flaws[vuln_name]["ref"].items():
- ${ref_name | h}
% endfor

% endif % endfor % for i, anomaly_name in enumerate(anomalies): % if len(anomalies[anomaly_name]):

### ${anomaly_name}

Description
  ${flaws[anomaly_name]["desc"] | h}

% for j, anomaly in enumerate(anomalies[anomaly_name]):

#### Anomaly found in ${anomaly["path"] | h}

    ${anomaly["info"] | h}

    ${anomaly["http_request"] | h}

    ${anomaly["curl_command"] | h}

% endfor

Solutions
  ${flaws[anomaly_name]["sol"]}

##### References

% for ref_name, ref_url in flaws[anomaly_name]["ref"].items():
- ${ref_name | h}
% endfor

% endif % endfor % for i, additional_name in enumerate(additionals): % if len(additionals[additional_name]):

### ${additional_name}

Description
  ${flaws[additional_name]["desc"] | h}

% for j, additional in enumerate(additionals[additional_name]):

#### Additional found in ${additional["path"] | h}

    ${additional["info"] | h}

    ${additional["http_request"] | h}

    ${additional["curl_command"] | h}

% endfor

Solutions
  ${flaws[additional_name]["sol"]}

##### References

% for ref_name, ref_url in flaws[additional_name]["ref"].items():
- ${ref_name | h}
% endfor

% endif % endfor